/**
 * @用途 定义gc (全局通信 Global communication)
 * @作者 黄敏
 * @创建时间 2021-05-28 21:48
 **/

/*
 * 为gc的主题制定格式，
 * key是主题，值为参数，
 * */

enum MqttStatus {
	noConnect = 0,
	connected = 1,
	close = 2,
	error = 3
}

export interface IpcParams {

	系统mqtt连接状态变化: [MqttStatus]

	登录状态linkedin更新: ['nologin'?]
	系统已退出登录: [boolean] // param[0]:boolean //是否是切换团队
	系统更新状态变化: [{ status?: number; msg?: string; percent?: number; info?: { version: string } }]
	系统检查更新: []
	系统更新并重启: []

	webview右键菜单创建: [number] //webContentId
	拖曳状态: [boolean, { type: string; data: any }?] //判断是否在拖曳中,如果为true,第二参数为拖曳的数据
	screenshot截图成功: [string] //@param0 返回base64
	导出xlsx: [{ fileName: string; data: (string | number)[][]; cols?: { width?: number; height?: number }[] }]
	弹窗加载完成: [string] // @param 弹窗名

	重新获取扩展列表: [],
	更新扩展列表: [Crawler.Extension[]]
	mqtt更新扩展列表: []
	初始化扩展请求: [string] //string是一个key
	初始化扩展列表: [string, Crawler.Extension[]] //string是一个key
}

export type Subscribes = {
	[P in keyof IpcParams]: (...param: [...IpcParams[P]]) => void
}

export type IpcTopic = keyof IpcParams

//gc通讯类
export interface Client {
	//发送消息

	on<T extends string>(topic: T, param: T extends keyof Subscribes ? Subscribes[T] : (...p: any[]) => void, noSendSub?: boolean): void

	send<T extends string>(topic: T, ...param: T extends IpcTopic ? IpcParams[T] : [any, 'ignore']): void //|any[]

	//发送消息，但只发给主进程
	sendMain<T extends string>(topic: T, ...param: T extends keyof IpcParams ? IpcParams[T] : any[]): void

	//只在当前进程发送
	sendCurrent<T extends string>(topic: T, ...param: T extends keyof IpcParams ? IpcParams[T] : any[]): void

	//放送到指到窗口
	sendToWebContents<T extends string>(webContents: number, topic: T, param?: T extends keyof IpcParams ? IpcParams[T] : any): void

	//订阅
	subscribes(subs: Partial<Subscribes>): void

	//取消订阅
	unsubscribes(subs: Partial<Subscribes>): void
}
