export declare const MezzFileType: Readonly<{
    未知: 0;
    图片: 1;
    音频: 2;
    视频: 3;
    word: 4;
    excel: 5;
    ppt: 6;
    pdf: 10;
    eml: 11;
}>;
export declare const MqttStatus: Readonly<{
    noConnect: 0;
    connected: 1;
    close: 2;
    error: 3;
}>;
interface matchSortOption {
    same: number;
    company_info: Object;
    sort: number;
    sortype: number;
    [name: string]: any;
}
interface Perform {
    (cb?: () => void | Promise<any>): void;
    timeoutId: any;
    clear(): void;
}
declare function isDev(): boolean;
declare function trim(str: string, s?: string): string;
declare function ltrim(str: string, s?: string): string;
declare function rtrim(str: string, s?: string): string;
/**
 * 是否是普通JavaScript对象。只返回boolean
 */
declare function isObject(obj: any): boolean;
/**
 * 是否是中文
 * @str
 * @include //包含中文
 * */
declare function isChn(str: string, include?: boolean): boolean;
/**
 * 是否是英文名字
 * @str
 * */
declare function isEnn(str: string): boolean;
declare function compare(property: string): (a: any, b: any) => number;
/**
 * 替换字符串中的重音字符
 * @param str
 */
declare function normalizeChars(str: string): string;
export declare function htmlToDom(html: string, tag?: keyof HTMLElementTagNameMap): HTMLObjectElement | HTMLElement | HTMLAnchorElement | HTMLParagraphElement | HTMLQuoteElement | HTMLAreaElement | HTMLAudioElement | HTMLBaseElement | HTMLBodyElement | HTMLBRElement | HTMLButtonElement | HTMLCanvasElement | HTMLTableCaptionElement | HTMLTableColElement | HTMLDataElement | HTMLDataListElement | HTMLModElement | HTMLDetailsElement | HTMLDialogElement | HTMLDivElement | HTMLDListElement | HTMLEmbedElement | HTMLFieldSetElement | HTMLFormElement | HTMLHeadingElement | HTMLHeadElement | HTMLHRElement | HTMLHtmlElement | HTMLIFrameElement | HTMLImageElement | HTMLInputElement | HTMLLabelElement | HTMLLegendElement | HTMLLIElement | HTMLLinkElement | HTMLMapElement | HTMLMenuElement | HTMLMetaElement | HTMLMeterElement | HTMLOListElement | HTMLOptGroupElement | HTMLOptionElement | HTMLOutputElement | HTMLPictureElement | HTMLPreElement | HTMLProgressElement | HTMLScriptElement | HTMLSelectElement | HTMLSlotElement | HTMLSourceElement | HTMLSpanElement | HTMLStyleElement | HTMLTableElement | HTMLTableSectionElement | HTMLTableCellElement | HTMLTemplateElement | HTMLTextAreaElement | HTMLTimeElement | HTMLTitleElement | HTMLTableRowElement | HTMLTrackElement | HTMLUListElement | HTMLVideoElement;
declare class Util {
    trim: typeof trim;
    rtrim: typeof rtrim;
    ltrim: typeof ltrim;
    isDev: typeof isDev;
    isObject: typeof isObject;
    isChn: typeof isChn;
    isEnn: typeof isEnn;
    compare: typeof compare;
    normalizeChars: typeof normalizeChars;
    htmlToDom: typeof htmlToDom;
    devlog(...data: any): void;
    /**
     * 创建一个纯函数的缓存版本。
     */
    cached(fn: Function): (str: string, s2?: string) => any;
    sameText(str1: string, str2: string, isMatchCase?: boolean, isContains?: boolean): boolean;
    /**
     * 一维数组去重
     * @param  {Array} arr  一维数组
     * @return {any[]} 去重后的一维数组
     * */
    arrayUnique<T>(arr: T[]): T[];
    /**
     * 复制文本，执行该函数，文本将会写入的粘贴板，后续用户可以进行粘贴操作
     * @param {String} string 需要复制的文本
     **/
    copyText(string: string): void;
    /**
     * 把\r\n换行符转成html的<br>换行符
     * @param {String} string 字符串
     * */
    rnTobr(string: string): string;
    /**
     *
     * 加粗匹配的关键字
     * @param str匹配的内容
     * @param key匹配关键字
     * @param color 可选 匹配关键字的颜色，默认为绿色;
     */
    boldKey(str: string, key: string | string[], color?: string): string;
    /**
     *首字母大字
     * @param {String}str 字符串
     * @param {Boolean}isWord 是否以单词为分界
     */
    capitalize(str: string, capitalizeWords?: boolean): string;
    /**
     * 判断元素是否在数组里
     * @param arr 原数组
     * @param item 元素
     * @return Boolean
     */
    inArray(arr: any[], item: any): boolean;
    /**
     * 从数组中删除所有匹配的元素，此操作会在原数组中直接删除
     * @param arr 原数组
     * @param item 要删除的项
     * @returns 被删除的元素，如果没有元素被删除则返回空数组
     */
    removeArrayItem<T>(arr: T[], item: T): T[];
    isEmptyObject(obj: Object): boolean | undefined;
    /**
     * 从网址中提取出域名，可以接收baidu.com, www.baidu.com,https://www.baidu.com等格式，如果网址不合法，返回Null
     * @param url 网址字符串
     * @returns 返回域名字符串或者 null 如果不是一个有效的网址的话
     */
    getDomain(url: string): string | null;
    sleep(millisecond: number): Promise<unknown>;
    timeoutPerform(time: number): Perform;
    intervalPerform(time: number): (cb: Function) => void;
    nameToFirstLastName(name: string, id?: number): {
        last_name: string;
        first_name: string;
        gender: number;
    };
    matchSort(data: matchSortOption[], key: string, mkey: string): matchSortOption[];
    static fileType: {
        [key: string]: string;
    };
    removeEmoji(str: string): string;
    delSpecial(s: string): string;
    scopeRandom(min: number, max: number): number;
    getUrlParam(key: string, url?: string): string;
    /**
     * 将一个一维对象转换为URL参数字符串。
     * @param obj 一个一维对象，其中包含要转换为URL参数的键值对。
     * @param url (可选) 一个字符串，用于指定要与生成的URL参数字符串合并的URL。如果省略此参数，则返回URL参数字符串本身。
     * @returns 返回一个字符串，包含将给定对象转换为URL参数后的结果。如果提供了URL参数，则返回完整的URL字符串。
     */
    createUrlParam(obj: Record<string, string | number | boolean | undefined>, url?: string): string;
    /**
     * 是否是字符串
     */
    isString(v: any): boolean;
    /**
     * 是否是boolean
     */
    isBoolean(v: any): boolean;
    isDomain(v: string): boolean;
    filterHTMLTag(msg: string): string;
    isIntranet(URL: string): boolean;
    getFullName(firstName: string, lastName: string): string;
    getWeChatType(str: string): 'qr' | 'img' | 'id';
    private static lastKey;
    getUniqueKey(): string;
    toLowerAndTrim(v: any): string;
    asyncDelay(time: number, maxTime?: number): Promise<unknown>;
    titleCase(str: string): string;
    isDesktopFiles(type: string): boolean;
    isExecl(type: string): boolean;
    formatCapital(num: string): string | 0;
    /**
     * 获取元素距离顶部的高度
     * @param el
     */
    getElementOffset(el: HTMLElement): {
        top: number;
        left: number;
    };
    getWebSite(text: string): {
        data: string[];
        text: string;
    };
    strToRegExp(str: string): RegExp | undefined;
}
declare let funs: Util;
export default funs;
