/**
 * @用途 定义gc (全局通信 Global communication)
 * @作者 黄敏
 * @创建时间 2021-05-28 21:48
 **/
declare enum MqttStatus {
    noConnect = 0,
    connected = 1,
    close = 2,
    error = 3
}
export interface IpcParams {
    系统mqtt连接状态变化: [MqttStatus];
    登录状态linkedin更新: ['nologin'?];
    系统已退出登录: [boolean];
    系统更新状态变化: [{
        status?: number;
        msg?: string;
        percent?: number;
        info?: {
            version: string;
        };
    }];
    系统检查更新: [];
    系统更新并重启: [];
    webview右键菜单创建: [number];
    拖曳状态: [boolean, {
        type: string;
        data: any;
    }?];
    screenshot截图成功: [string];
    导出xlsx: [{
        fileName: string;
        data: (string | number)[][];
        cols?: {
            width?: number;
            height?: number;
        }[];
    }];
    弹窗加载完成: [string];
    重新获取扩展列表: [];
    更新扩展列表: [Crawler.Extension[]];
    mqtt更新扩展列表: [];
    初始化扩展请求: [string];
    初始化扩展列表: [string, Crawler.Extension[]];
}
export type Subscribes = {
    [P in keyof IpcParams]: (...param: [...IpcParams[P]]) => void;
};
export type IpcTopic = keyof IpcParams;
export interface Client {
    on<T extends string>(topic: T, param: T extends keyof Subscribes ? Subscribes[T] : (...p: any[]) => void, noSendSub?: boolean): void;
    send<T extends string>(topic: T, ...param: T extends IpcTopic ? IpcParams[T] : [any, 'ignore']): void;
    sendMain<T extends string>(topic: T, ...param: T extends keyof IpcParams ? IpcParams[T] : any[]): void;
    sendCurrent<T extends string>(topic: T, ...param: T extends keyof IpcParams ? IpcParams[T] : any[]): void;
    sendToWebContents<T extends string>(webContents: number, topic: T, param?: T extends keyof IpcParams ? IpcParams[T] : any): void;
    subscribes(subs: Partial<Subscribes>): void;
    unsubscribes(subs: Partial<Subscribes>): void;
}
export {};
