/// <reference path="../../types.d.ts" />
import gc from './src/gc';
import mqtt from './src/mqtt';
import util, { MezzFileType, MqttStatus } from '../common/util';
import Ajax from '../common/ajax';
import { CrawlerUtil } from './src/crawler/utils';
import CrawlerDb from './src/crawler/database';
import { AxiosRequestConfig, AxiosStatic, Canceler as C } from 'axios';
import NameSplit from '../web/src/name-split';
import error from '../common/error';
import DateTime from '../web/src/date-time';
import ContactInfo from '../web/src/contactInfo';
import Linkedin, { LinkedinAccount } from './src/linkedin';
import CountryClass, { Country as Co, CountryBase as CB } from '../web/src/country';
import * as Gc from "../gc.type";
/**
 * @desc 渲染进程全局变量
 * @author 黄敏
 * @创建时间 2022-08-02 15:15
 **/
type ValueOf<T> = T[keyof T];
declare global {
    namespace Axios {
        type Canceler = C;
        type RequestConfig = AxiosRequestConfig;
    }
    namespace ff {
        type MezzFileType = ValueOf<typeof MezzFileType>;
        type MqttStatus = ValueOf<typeof MqttStatus>;
        namespace mqtt {
            interface Subs {
                [topic: string]: (...data: any) => void;
            }
        }
        namespace gc {
            type Client = Gc.Client;
            type IpcTopic = Gc.IpcTopic;
            type Subscribes = Gc.Subscribes;
        }
        namespace country {
            type CountryBase = CB;
            type Country = Co;
        }
        namespace linkedin {
            type AccountStatus = LinkedinAccount;
        }
    }
}
declare global {
    var extensions: Crawler.Extension[];
    var anchorConfig: Record<string, Crawler.AnchorsConfig | null>;
    var ff: Readonly<{
        MezzFileType: typeof MezzFileType;
        MqttStatus: typeof MqttStatus;
        Ajax: typeof Ajax;
        util: typeof util;
        error: typeof error;
        gc: typeof gc;
        mqtt: typeof mqtt;
        axios: AxiosStatic;
        nameSplit: NameSplit;
        dateTime: typeof DateTime;
        contactInfo: typeof ContactInfo;
        linkedin: Linkedin;
        country: CountryClass;
        crawler: {
            util: CrawlerUtil;
            db: CrawlerDb;
        };
    }>;
}
export {};
