/**
 * @用途
 * @author 黄敏
 * @创建时间 2022-08-08 08:39
 **/
declare class CrawlerDb {
    private db;
    private isDisable;
    disableDb(): void;
    enableDb(): void;
    constructor();
    opendb(): void;
    /**
     * 保存联系人信息
     * @param id {String} 唯一id ，一般使用urlId或url
     * @param {mixed} contact 存入数据存的内容
     * @param {string} type 类型，如linkedin、facebook、等
     * @return 无返回值
     * */
    saveContact(id: string | number, content: Crawler.Contact, type?: string): void;
    /**
     * 从本地获取联系人信息
     * @param {String} id 获取指定id的内容，id一般为urlid或url
     * @param {String} type 数据类型，有值：default|linkedin|facebook|twitter|google
     * @return {Promise(Crawler.Contact | null)}
     * */
    getContact(id: string | number, type?: string): Promise<Crawler.Contact | null>;
    /**
     * 保存公司信息
     * @param id {String} 唯一id ，一般使用urlId或url
     * @param type {String} 类型，可选linkedin facebook twitter default
     * @param {mixed} contact 存入数据存的内容
     * @return void
     * */
    saveAccount(id: number | string, company: Crawler.Company, type?: string, ext?: any | null): void;
    /**
     * 从本地获取公司信息
     * @param {String} id 获取指定id的内容，id一般为urlid或url
     * @param {String} type 数据类型，有值：default|linkedin|facebook|twitter|google
     * @return {Promise(Crawler.Company | null)}
     * */
    getAccount(id: number | string, type?: string): Promise<Crawler.Company | null>;
    /**
     * 从本地获取综合数据
     * @param {String} id 获取指定id的内容，id一般为urlid或url
     * @param {String} type 数据类型，有值：default|linkedin|facebook|twitter|google
     * @return {Promise(Crawler.Company | null)}
     * */
    getResult(id: number | string, type?: string): Promise<Crawler.Result | null>;
    /**
     * 保存公司信息
     * @param id {String} 唯一id ，一般使用urlId或url
     * @param type {String} 类型，可选linkedin facebook twitter default
     * @param {mixed} contact 存入数据存的内容
     * @return void
     * */
    saveResult(id: number | string, result: Crawler.Result, type?: string): void;
    saveTemp(id: number | string, content: any, day?: number): void;
    getTemp(id: string | number): Promise<any>;
    /**
     * 获取是否为朋友关系
     * @param uid
     * @param uuid暂时不用加uuid
     * */
    getValidationFriend(uid: string, type: string, uuid?: number | string): Promise<Crawler.FriendInfo | null>;
    saveValidationFriend(uid: string, type: string, friend: Crawler.FriendInfo, uuid?: number | string): Promise<void>;
    delValidationFriend(uid: string, type: string): Promise<void>;
    /**
     * 联系人与操作员（CM）的共同好友
     * @param id {String} 唯一id ，一般使用urlId或url
     * @param {mixed} contact 存入数据存的内容
     * @return 无返回值
     * */
    saveMutualFriends(id: string | number, content: Crawler.MutualFriends, type?: string): void;
    getMutualFriends(id: string | number, type?: string): Promise<Crawler.MutualFriends | null>;
}
export default CrawlerDb;
